function tdeck(filename,ix,iy)
%
%      contoue data produced from triple deck progem newton.f
%
%	tdeck(filename,ix,iy)
%
%	filename= name of file with data
%	ix = number of x steps (data 0:ix)
%	iy = number of y steps (data 0:iy)
%
%	can contour either streamlines or vorticity
%	depending on file called
%
ix1=ix+1;
iy1=iy+1;
mat1=[iy1 ix1];
mat2=[2 ix1];
mat3=[2 iy1];
file=fopen(filename,'r');
psi=fscanf(file,'%g',mat1);
phi=psi';
fclose(file);
file=fopen('fort.7','r');
datax=fscanf(file,'%g',mat2);
fclose(file);

x=datax(1,:);
length(x)
file=fopen('fort.8','r');
datay=fscanf(file,'%g',mat3);
y=datay(1,:);
length(y)
pm=2.5;
pl=-.5;
dp=(pm-pl)/10;
h=[0. 1 2 3 4 5 6 7 8 9];
[C,h1]=contour(x,y,psi,h);
%clabel(C,h1);
